[Libreoffice-commits] core.git: comphelper/source

Thorsten Behrens Thorsten.Behrens at CIB.de
Sat Jan 13 13:34:33 UTC 2018


 comphelper/source/misc/storagehelper.cxx |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit eea58228eabec225cfec49932ae0c7b0d79fdc7f
Author: Thorsten Behrens <Thorsten.Behrens at CIB.de>
Date:   Thu Jan 11 23:35:54 2018 +0100

    tdf#114550 use 32 bit random session key for gpg encryption
    
    Otherwise we'd need to pointlessly spread it to 32 bit down the
    road for AES.
    
    Change-Id: I7303be71fd855aa454d07fcae04d7f42e3c9cd9c
    Reviewed-on: https://gerrit.libreoffice.org/47781
    Reviewed-by: Thorsten Behrens <Thorsten.Behrens at CIB.de>
    Tested-by: Thorsten Behrens <Thorsten.Behrens at CIB.de>

diff --git a/comphelper/source/misc/storagehelper.cxx b/comphelper/source/misc/storagehelper.cxx
index dd52b7f6181a..c312b397974f 100644
--- a/comphelper/source/misc/storagehelper.cxx
+++ b/comphelper/source/misc/storagehelper.cxx
@@ -448,8 +448,8 @@ uno::Sequence< beans::NamedValue > OStorageHelper::CreateGpgPackageEncryptionDat
 
     rtlRandomPool aRandomPool = rtl_random_createPool();
 
-    // get 16 random chars out of it
-    uno::Sequence < sal_Int8 > aVector(16);
+    // get 32 random chars out of it
+    uno::Sequence < sal_Int8 > aVector(32);
     rtl_random_getBytes( aRandomPool, aVector.getArray(), aVector.getLength() );
 
     rtl_random_destroyPool(aRandomPool);


More information about the Libreoffice-commits mailing list